<template>
  <div class="sales-details">
    <div v-if="isDetail" class="detail-top">
      <DetailListCommonBtn />
    </div>

    <div v-else class="filter">
      <div class="filter-card">
        <CommonSearch
          :show-add="false"
          :show-download="false"
          :amount-view="false"
          :show-action-btn="false"
          placeholder="请输入订单编号"
          @searchClick="onFilterSearch"
        >
          <template slot="leftButton">
            <el-button size="small" type="primary" @click="addBtnClick">新建</el-button>
            <!-- <el-button size="small"  @click="delClick">删除</el-button> -->
          </template>
        </CommonSearch>
      </div>
    </div>

    <div class="body">
      <!-- <div class="body-card"> -->
      <div class="content-top">
        <div class="list-view">
          <TableCommonView
            ref="tableListRef"
            :show-summary="showSummary"
            :table-list="tableList"
            @selClientClick="selClientClick"
            @selCommonClick="selCommonClick"
            @getSelectArray="getSelectArray"
            @selTableCol="selTableCol"
            @tableRowClick="tableRowClick"
            :selectClassRow="selectRow"
          >
            <template slot="tableButton">
              <el-table-column label="操作" width="180">
                <template slot-scope="scope">
                  <el-button @click.stop="handleClick(scope.row, '查看')" type="text" size="small">查看</el-button>
                  <template v-if="scope.row.status === 1">
                    <el-button @click.stop="handleClick(scope.row, '编辑')" type="text" size="small">编辑</el-button>
                    <el-button @click.stop="submitClick(scope.row)" type="text" size="small">确认提交</el-button>
                    <!-- <el-button @click="delClick(scope.row.id)" type="text" size="small">删除</el-button> -->
                    <el-button @click.stop="closeClick(scope.row)" type="text" size="small">关闭</el-button>
                  </template>
                </template>
              </el-table-column>
            </template>
          </TableCommonView>
        </div>
        <div class="btn-pager">
          <PagerView class="page" :pager-options="pagerOptions" v-on="pagerEvents" />
        </div>
      </div>
      <div class="content-bottom">
        <div class="bottom-tabs" :class="!isDetail ? 'bgcGrey' : 'bgcWhite'">
          <div
            class="tab-pane"
            @click="getTab(0)"
            :style="{
              background: TabsIndex == 0 ? '#2a78fb' : '#F1F3F8',
              color: TabsIndex == 0 ? '#fff' : '#666'
            }"
          >
            产品信息
          </div>
          <div
            class="tab-pane"
            @click="getTab(1)"
            :style="{
              background: TabsIndex == 1 ? '#2a78fb' : '#F1F3F8',
              color: TabsIndex == 1 ? '#fff' : '#666'
            }"
          >
            发货信息
          </div>
          <div
            class="tab-pane"
            @click="getTab(2)"
            :style="{
              background: TabsIndex == 2 ? '#2a78fb' : '#F1F3F8',
              color: TabsIndex == 2 ? '#fff' : '#666'
            }"
          >
            制造信息
          </div>
          <div
            class="tab-pane"
            @click="getTab(3)"
            :style="{
              background: TabsIndex == 3 ? '#2a78fb' : '#F1F3F8',
              color: TabsIndex == 3 ? '#fff' : '#666'
            }"
          >
            采购信息
          </div>
        </div>
        <div class="list-view">
          <TableCommonView :loading="loading" :table-list="productTableList" @selTableCol="selBottomTableCol">
            <!-- <template slot="tableButton">
              <el-table-column label="操作" width="160" fixed="right">
                <template slot-scope="scope">
                  <el-button @click="viewClick(scope.row)" type="text" size="small">查看</el-button>
                </template>
              </el-table-column>
            </template> -->
          </TableCommonView>
        </div>
      </div>
    </div>
    <!-- 确认提交-选择项目 -->
    <el-dialog title="请选择项目" :visible.sync="projectListShow" width="400px" :before-close="handleClose">
      <el-form label-width="100px" class="demo-ruleForm" ref="form" :rules="rules" :model="projects">
        <el-form-item label="选择项目" prop="projectId">
          <el-select v-model="projects.projectId" placeholder="请选择" size="mini" style="width: 100%">
            <el-option
              v-for="item in projectList"
              :key="item.projectId"
              :label="item.projectName"
              :value="item.projectId"
            >
            </el-option>
          </el-select>
        </el-form-item>
      </el-form>
      <span slot="footer" class="dialog-footer dialog_btn">
        <el-button @click="projectListShow = false">取 消</el-button>
        <el-button type="primary" @click="affirmCommitBtn">确 定</el-button>
      </span>
    </el-dialog>
    <!-- 新建/编辑 -->
    <AddSalesDetailsDialog
      v-if="editConfig.visible"
      :edit-common-config="editConfig"
      @addCollectionPlanClick="addCollectionPlanClick"
    />
    <!-- 销售明细详情 -->
    <DetailSpecification v-if="specificationDetail.visible" :specification-detail="specificationDetail" />
    <!-- 客户详情 -->
    <DetailClientManage v-if="clientDeail.visible" :client-manage-detail="clientDeail" />
    <!-- 新建 收款计划 -->
    <AddCollectionPlan v-if="addCollectionConfig.visible" :edit-common-config="addCollectionConfig" />
  </div>
</template>

<script>
import AddSalesDetailsDialog from "@/views/sales/salesDetails/AddSalesDetailsDialog"
import {
  getSalesDetailsList,
  getDelSalesDetails,
  getProductInventoryInfo,
  getProductOrderInfo,
  updateStatus,
  getProjectList,
  sendSalesDetailsToOtherSystem
} from "@/api/sales/salesDetails"
import pageMixin from "@/components/makepager/pager/mixin/pageMixin"
import DetailSpecification from "@/views/sales/salesDetails/DetailSpecification"
import AddCollectionPlan from "@/views/other/payment/collectionPlan/AddCollectionPlan"
import { getDataByType } from "@/api/data"
export default {
  name: "SalesDetails",
  props: {
    isDetail: {
      type: Boolean,
      default: false
    },
    addConfig: {
      type: Object,
      default: () => {
        return {}
      }
    }
  },
  mixins: [pageMixin],
  components: {
    AddSalesDetailsDialog,
    DetailSpecification,
    DetailClientManage: () => import("@/views/client/client/DetailClientManage"),
    AddCollectionPlan
  },
  computed: {
    searchCommonHeight() {
      return this.$refs.searchCommonView.offsetHeight
    }
  },
  data() {
    // 产品信息
    const productColumn = [
      { label: "产品编号", prop: "number", default: true },
      { label: "产品名称", prop: "name" },
      { label: "数量", prop: "amount" },
      { label: "单位", prop: "unit" },
      { label: "销售单价", prop: "salePrice", price: true },
      { label: "成本单价", prop: "cost" },
      { label: "毛利", prop: "profit" },
      { label: "毛利率(%)", prop: "margin" },
      { label: "价税合计", prop: "total", price: true }
    ]
    // 库存信息
    const inventoryColumn = [
      { label: "产品编号", prop: "number", default: true },
      { label: "产品名称", prop: "name" },
      { label: "订单数量", prop: "orderAmount" },
      { label: "发货单", prop: "invoice" },
      { label: "承运商", prop: "carrier" },
      { label: "运单号", prop: "waybill" },
      { label: "仓库", prop: "warehouse" },
      { label: "在库数量", prop: "amount" },
      { label: "可用库存", prop: "availableNumber" },
      { label: "单位", prop: "unit" }
    ]
    // 制造信息
    const makeColumn = [
      { label: "生产订单", prop: "orderId", default: true },
      { label: "产品名称", prop: "productName" },
      { label: "订单状态", prop: "orderStatus" },
      { label: "工单编号", prop: "workOrderId" },
      { label: "工单状态", prop: "workOrderStatus" },
      { label: "计划开始时间", prop: "startTime" },
      { label: "计划结束时间", prop: "endTime" }
    ]
    // 采购信息
    const purchaseColumn = [
      {
        label: "采购单号",
        prop: "purchaseNumber",
        default: true
      },
      {
        label: "采购单名称",
        prop: "purchaseName"
      },
      {
        label: "供应商名称",
        prop: "supplierName"
      },
      {
        label: "采购数量",
        prop: "amount"
      },
      {
        label: "状态",
        prop: "status",
        isCallMethod: true,
        getCallMethod: this.getpurchaseStatus
      }
    ]
    return {
      tableList: {},
      searchOptions: [],
      editConfig: {
        visible: false,
        title: "新建",
        infomation: {}
      },
      showSummary: {
        show: false,
        sumProp: [
          "receiveTotalAmount",
          "amountTotal",
          "amountReceivable",
          "invoicedAmount",
          "uninvoicedAmount",
          "number",
          "unOutoundNo",
          "taxUnitPrice",
          "priceTax"
        ],
        mergeNumber: 6
      },
      specificationDetail: {
        visible: false,
        infomation: {}
      },
      clientDeail: {
        visible: false,
        infomation: {}
      },
      selValueList: [],
      search_map: {},
      searchSel: {
        value: "number",
        label: "订单编号"
      },
      keyword: "",
      keywordType: "",
      addCollectionConfig: {
        visible: false,
        title: "新建",
        infomation: {}
      },
      tableColumn: [
        { label: "订单编号", prop: "number", isCommonClick: true, default: true },
        { label: "销售负责人", prop: "member_name" },
        { label: "签约日期", prop: "signTime" },
        { label: "交付日期", prop: "deliveryDate" },
        { label: "订单来源", prop: "source" },
        { label: "合计", prop: "amountTotal", price: true },
        { label: "状态", prop: "status", isCallMethod: true, getCallMethod: this.getStatus }
      ],
      showCol: ["订单编号", "销售负责人", "签约日期", "交付日期", "订单来源", "合计", "状态"],
      tableBottomColumn: [],
      showBottomCol: [],
      TabsIndex: "0",
      productTableList: {},
      productColumn: productColumn,
      showProductCol: ["产品编号", "产品名称", "数量", "单位", "销售单价", "成本单价", "毛利", "毛利率(%)", "价税合计"],
      inventoryColumn: inventoryColumn,
      showInventoryCol: [
        "产品编号",
        "产品名称",
        "订单数量",
        "发货单",
        "承运商",
        "运单号",
        "仓库",
        "在库数量",
        "可用库存",
        "单位"
      ],
      makeColumn: makeColumn,
      showMakeCol: ["生产订单", "产品名称", "订单状态", "工单编号", "工单状态", "计划开始时间", "计划结束时间"],
      // 采购
      purchaseColumn: purchaseColumn,
      showPurchaseCol: ["采购单号", "采购单名称", "供应商名称", "采购数量", "状态"],
      selectRow: {},
      projectList: [],
      projectListShow: false,
      projects: {
        projectId: ""
      },
      thatRow: {},
      rules: {
        projectId: [{ required: true, message: "请选择项目", trigger: "change" }]
      },
      purchaseStatusList: getDataByType("purchaseStatus"),
      loading: false
    }
  },
  created() {
    this.setTable()
    if (!this.isDetail) {
      this.keyword = ""
      this.keywordType = ""
    } else {
      this.keyword = this.addConfig.keyword
      this.keywordType = this.addConfig.keywordType
    }
    this.getData()
    this.getProjectList()
  },
  methods: {
    getpurchaseStatus(val) {
      if (val) {
        for (let i in this.purchaseStatusList) {
          if (this.purchaseStatusList[i].id == val) {
            return this.purchaseStatusList[i].name
          }
        }
      } else {
        return "--"
      }
    },
    setTable() {
      // top 明细单列表
      this.tableList = {
        selectIndex: true,
        tableInfomation: [],
        allcol: [],
        showcol: this.showCol,
        tableColumn: this.setColumnVisible(this.showCol, this.tableColumn)
      }
      this.setTableList(this.tableList)

      // bottom 产品信息/库存信息/制造信息列表
      this.tableBottomColumn = this.productColumn
      this.showBottomCol = this.showProductCol
      this.setBottomList()
    },
    // bom 列表
    setBottomList() {
      this.productTableList = {
        selectIndex: true,
        tableInfomation: [],
        allcol: [],
        showcol: this.showBottomCol,
        tableColumn: this.setColumnVisible(this.showBottomCol, this.tableBottomColumn)
      }
      this.setTableList(this.productTableList)
    },
    setTableList(tableList) {
      tableList.allcol = tableList.tableColumn.filter((ele) => !ele.default).map((ele) => ele.label)
      this.searchOptions = []
      for (let i = 0; i < tableList.tableColumn.length; i++) {
        const label = tableList.tableColumn[i].label
        const value = tableList.tableColumn[i].prop
        this.searchOptions.push({ value: value, label: label })
      }
    },
    setColumnVisible(showCol, tableColumn) {
      return tableColumn.map((ele) => {
        return {
          ...ele,
          isShowColumn: showCol.includes(ele.label)
        }
      })
    },
    // top 明细单
    selTableCol(val) {
      this.showcol = val
      this.tableList.tableColumn = this.setColumnVisible(val, this.tableColumn)
    },
    // bottom 产品信息
    selBottomTableCol(val) {
      this.showcol = val
      this.productTableList.tableColumn = this.setColumnVisible(val, this.tableBottomColumn)
    },
    // 请求数据
    async getData() {
      let params = {}
      console.log(this.addConfig)
      if (this.addConfig.keywordType === "客户名称") {
        params = {
          clientId: this.addConfig.client_id,
          page: this.pagerOptions.currPage,
          pageSize: this.pagerOptions.pageSize
        }
      } else if (this.addConfig.keywordType === "销售机会") {
        params = {
          saleChanceId: this.addConfig.sale_chance_id,
          page: this.pagerOptions.currPage,
          pageSize: this.pagerOptions.pageSize
        }
      } else if (this.addConfig.keywordType === "销售子单") {
        params = {
          number: this.addConfig.subbill_name,
          page: this.pagerOptions.currPage,
          pageSize: this.pagerOptions.pageSize
        }
      } else {
        params = {
          keyword: this.keyword,
          keywordType: this.keywordType,
          page: this.pagerOptions.currPage,
          pageSize: this.pagerOptions.pageSize
        }
      }
      this.loading = true
      await getSalesDetailsList(params)
        .then((res) => {
          if (res.code === 200) {
            if (res.data.list && res.data.list.length > 0) {
              const list = res.data.list.map((item) => {
                return {
                  ...item,
                  client_name: item.client.name,
                  member_name: item.Member.username,
                  source: ""
                }
              })
              this.tableList.tableInfomation = list || []
              this.pagerOptions.totalCount = res.data.count
              if (res.data.count > 0) {
                this.selectRow = this.tableList.tableInfomation.length > 0 ? this.tableList.tableInfomation[0] : {}
                this.tableRowClick(this.selectRow)
              }
            } else {
              this.tableList.tableInfomation = []
            }
          } else {
            this.tableList.tableInfomation = []
          }
          this.loading = false
        })
        .catch((err) => {
          console.log(err)
          this.tableList.tableInfomation = []
          this.loading = false
        })
    },
    // 获取产品/库存信息
    async getProductInventoryInfo(row) {
      if (this.TabsIndex == 0 || row.status == 1) {
        this.productTableList.tableInfomation = row.products || []
      } else {
        if (row.number) {
          this.loading = true
          await getProductInventoryInfo(row.number)
            .then((res) => {
              this.productTableList.tableInfomation = res.data?.length > 0 ? res.data : []
              this.loading = false
            })
            .catch(() => {
              this.productTableList.tableInfomation = []
              this.loading = false
            })
        }
      }
    },
    // 获取制造信息
    async getProductOrderInfo(number) {
      if (number) {
        this.loading = true
        await getProductOrderInfo(number)
          .then((res) => {
            if (this.TabsIndex == 3) {
              this.productTableList.tableInfomation = res.data && res.data.purchaseInfo ? res.data.purchaseInfo : []
            } else {
              this.productTableList.tableInfomation = res.data && res.data.makeInfo ? res.data.makeInfo : []
            }
            this.loading = false
          })
          .catch(() => {
            this.productTableList.tableInfomation = []
            this.loading = false
          })
      }
    },
    // 搜索
    onFilterSearch(searchText) {
      this.keyword = searchText ?? ""
      this.keywordType = "订单编号"
      this.pagerOptions.currPage = 1
      this.getData()
    },
    // 新建
    addBtnClick() {
      this.editConfig.visible = true
      this.editConfig.title = "新建"
      console.log(this.addConfig)
      this.editConfig.infomation = {
        ...this.addConfig,
        currency: "人民币",
        sale_chance_name: "",
        subbill_name: "",
        client_name: this.addConfig?.client_name ?? "",
        quotation_number: ""
      }
    },
    // 查看 编辑
    handleClick(row, title) {
      let params = JSON.parse(JSON.stringify(row))
      this.editConfig.title = title
      this.editConfig.infomation = {
        ...params,
        currency: "人民币",
        sale_chance_name: params.saleChance.name,
        deliverType: params.deliverType === 0 ? "" : params.deliverType,
        quotation_number: params.quotation.number
      }
      this.editConfig.visible = true
    },
    // 确认提交
    async submitClick(row) {
      this.thatRow = row
      if (row.projectId == "") {
        this.projectListShow = true
      } else {
        let params = {
          ...row,
          status: 2
        }
        await sendSalesDetailsToOtherSystem(params).then((res) => {
          if (res.code == 200) {
            this.$message.success("成功推送至aps系统")
            this.getData()
            this.thatRow.status = 2
          }
        })
      }
    },
    // 关闭
    closeClick(row) {
      console.log(row, "关闭")
      this.updateStatus(row.id, 4)
    },
    // 修改状态
    async updateStatus(id, status) {
      await updateStatus({
        id: id,
        status: status
      }).then((res) => {
        console.log(res)
        if (res.code == 200) {
          this.$message.success("关闭成功")
          this.getData()
        }
      })
    },
    // 删除
    delClick(rowID) {
      console.log(rowID, "xxxxshanchu")
      // if (this.selValueList && this.selValueList.length > 0) {
      this.$confirm("是否确认删除?", "警告", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning"
      })
        .then(() => {
          getDelSalesDetails({ ids: [rowID] }).then((response) => {
            if (response.code === 200) {
              this.$message.success("删除成功")
              this.getData()
            } else {
              this.$message.warning("删除失败")
            }
          })
        })
        .catch(() => {})
      // } else {
      //   this.$message.warning("请至少选择一条记录")
      // }
    },
    getSelectArray(val) {
      console.log(val)
      this.selValueList = []
      const list = val.map((item) => {
        return item.id
      })
      this.selValueList = list
    },
    // 客户名称详情
    selClientClick(row) {
      console.log(row)
      this.clientDeail.visible = true
      this.clientDeail.infomation = {
        ...row.client,
        member: row.Member,
        client_name: row.client.name,
        client_level: row.client.client_level.name,
        client_status: row.client.client_status.name
      }
    },
    // 联系人详情
    selCommonClick(row) {
      this.specificationDetail.infomation = { ...row }
      this.specificationDetail.visible = true
    },
    addCollectionPlanClick(row) {
      this.addCollectionConfig.visible = true
      this.addCollectionConfig.title = "新建"
      this.addCollectionConfig.sourceType = 1
      this.addCollectionConfig.infomation = { ...row }
    },
    //获取当前选中资源的id
    getTab(tab) {
      this.TabsIndex = tab
      if (this.TabsIndex == 0) {
        // 产品信息列表
        this.tableBottomColumn = this.productColumn
        this.showBottomCol = this.showProductCol
        this.setBottomList()
        this.getProductInventoryInfo(this.selectRow)
      } else if (this.TabsIndex == 1) {
        // 库存信息列表
        this.tableBottomColumn = this.inventoryColumn
        this.showBottomCol = this.showInventoryCol
        this.setBottomList()
        if (this.selectRow.status == 1) {
          this.productTableList.tableInfomation = []
        } else {
          this.getProductInventoryInfo(this.selectRow)
        }
      } else if (this.TabsIndex == 2) {
        // 制造信息列表
        this.tableBottomColumn = this.makeColumn
        this.showBottomCol = this.showMakeCol
        this.setBottomList()
        this.getProductOrderInfo(this.selectRow.number)
      } else if (this.TabsIndex == 3) {
        // 采购信息列表
        this.tableBottomColumn = this.purchaseColumn
        this.showBottomCol = this.showPurchaseCol
        this.setBottomList()
        this.getProductOrderInfo(this.selectRow.number)
      }
    },
    // 状态
    getStatus(val) {
      return val === 1 ? "待确认" : val === 2 ? "待出库" : val === 3 ? "出库完成" : val === 4 ? "已关闭" : "--"
    },
    // top 行点击
    tableRowClick(row) {
      this.selectRow = row
      if (this.TabsIndex == 0) {
        this.getProductInventoryInfo(this.selectRow)
      } else if (this.TabsIndex == 1) {
        if (this.selectRow.status == 1) {
          this.productTableList.tableInfomation = []
        } else {
          this.getProductInventoryInfo(this.selectRow)
        }
      } else if (this.TabsIndex == 2) {
        this.getProductOrderInfo(this.selectRow.number)
      } else if (this.TabsIndex == 3) {
        // 采购信息
        this.getProductOrderInfo(this.selectRow.number)
      }
    },
    // 获取项目列表
    async getProjectList() {
      await getProjectList({
        page: 1,
        pageSize: 100
      }).then((res) => {
        this.projectList = res.data ? res.data : []
      })
    },
    handleClose(done) {
      done()
    },

    saveParams() {
      let params = {
        address: this.thatRow.address || "",
        addressee: this.thatRow.addressee || "",
        clientId: this.thatRow.clientId || 0,
        conditions: this.thatRow.conditions || "",
        deliveryDate: this.thatRow.deliveryDate || "",
        memberId: this.thatRow.memberId || 0,
        number: this.thatRow.number || "",
        phone: this.thatRow.phone || "",
        products: this.thatRow.products,
        remark: this.thatRow.remark || "",
        saleChanceId: this.thatRow.saleChanceId || 0,
        saleType: this.thatRow.saleType || 0,
        signTime: this.thatRow.signTime || "",
        wechatOrderStatus: this.thatRow.wechatOrderStatus || 0,
        logisticCompany: this.thatRow.logisticCompany || "",
        logisticCost: this.thatRow.logisticCost || 0,
        logisticNumber: this.thatRow.logisticNumber || "",
        quotationId: this.thatRow.quotationId,
        deliverType: this.thatRow.deliverType || 0,
        status: this.thatRow.deliverType,
        projectId: this.projects.projectId || 0
      }
      return params
    },
    // 确认提交
    affirmCommitBtn() {
      let params = this.saveParams()
      this.$refs["form"].validate((valid) => {
        if (valid) {
          console.log()
          this.projectListShow = false
          console.log(params, "选择项目后的params")
          params.status = 2
          sendSalesDetailsToOtherSystem(params).then((res) => {
            if (res.code == 200) {
              this.$message.success("成功推送至aps系统")
              this.getData()
              this.thatRow.status = 2
            }
          })
        }
      })
    }
  }
}
</script>

<!-- Add "scoped" attribute to limit CSS to this component only -->
<style lang="scss" scoped>
::v-deep {
  .el-table .el-table__cell {
    padding: 0;
  }
  .el-table__footer-wrapper tbody td.el-table__cell {
    height: 48px;
  }
}

.sales-details {
  height: 100%;
  overflow: hidden;
  .filter {
    height: 80px;
    display: flex;
    align-items: center;
    padding: 12px 20px 0 20px;
    &-card {
      height: 80px;
      display: flex;
      align-items: center;
      box-sizing: border-box;
      padding: 10px 20px;
      flex: 1;
      border-radius: 12px;
      background-color: #fff;
    }
  }
  .body {
    box-sizing: border-box;
    padding: 10px 20px;
    border-radius: 12px;
    height: calc(100% - 70px);
    .content-top {
      background-color: #fff;
      border-radius: 12px;
      min-height: 70px;
      height: 48%;
      position: relative;
      .list-view {
        height: calc(100% - 60px);
      }
    }
    .content-bottom {
      .bottom-tabs {
        height: 40px;
        line-height: 40px;
        background: #e6ecf2;
        display: flex;
        .tab-pane {
          width: 100px;
          margin-right: 20px;
          font-size: 14px !important;
          text-align: center;
          cursor: pointer;
          background: #2a78fb;
          border-top-left-radius: 20px;
          border-top-right-radius: 20px;
        }
      }
      .lable-view {
        background: #e6ecf2;
        height: 40px;
        line-height: 40px;
        .name {
          border-left: 4px solid #2a78fb;
          padding-left: 10px;
        }
      }
      background-color: #fff;
      border-radius: 12px;
      min-height: 70px;
      height: calc(52% - 60px);
      margin-top: 10px;
      // padding: 10px 20px;
      .list-view {
        height: calc(100% - 10px);
      }
    }
    .btn-pager {
      display: flex;
      margin-top: 10px;
      .page {
        margin-left: auto;
      }
    }
  }
}

.bgcGrey {
  background: #e6ecf2;
}
.bgcWhite {
  background: #fff !important;
}
.el-form-item {
  width: 80%;
  margin: 20px auto;
}
::v-deep .el-dialog__footer {
  text-align: right !important;
  .el-button {
    margin-right: 10px;
  }
}
</style>
